@@ -56,7 +56,7 @@ def parse_hook_config(parsed_args):
             'binder_hooks', 'intent_hooks', 'broadcast_hooks', 'aes_hooks',
             'encodings_hooks', 'keystore_hooks', 'web_hooks', 'socket_hooks',
             'process_hooks', 'runtime_hooks', 'bluetooth_hooks', 'camera_hooks',
-            'clipboard_hooks', 'location_hooks', 'telephony_hooks'
+            'clipboard_hooks', 'location_hooks', 'telephony_hooks', 'bypass_hooks'
         ]}
     
     if parsed_args.hooks_crypto:
@@ -104,6 +104,11 @@ def parse_hook_config(parsed_args):
             'telephony_hooks': True
         })
     
+    if parsed_args.hooks_bypass:
+        hook_config.update({
+            'bypass_hooks': True
+        })
+    
     # Handle individual hook selections
     individual_hooks = {
         'enable_aes': 'aes_hooks',
@@ -126,7 +131,8 @@ def parse_hook_config(parsed_args):
         'enable_camera': 'camera_hooks',
         'enable_clipboard': 'clipboard_hooks',
         'enable_location': 'location_hooks',
-        'enable_telephony': 'telephony_hooks'
+        'enable_telephony': 'telephony_hooks',
+        'enable_bypass': 'bypass_hooks'
     }
     
     for arg_name, hook_name in individual_hooks.items():
@@ -181,6 +187,8 @@ Examples:
                       help="Enable fritap for TLS key extraction and traffic capture")
     args.add_argument("--fritap-output-dir", metavar="<directory>", required=False, default="./fritap_output",
                       help="Directory for fritap output files (default: ./fritap_output)")
+    args.add_argument("--custom-script", metavar="<path>", action="append", required=False,
+                      help="Load custom Frida script file(s) alongside dexray-intercept hooks (can be used multiple times)")
     
     # Hook selection arguments
     hooks = parser.add_argument_group("Hook Selection (all disabled by default)")
@@ -198,6 +206,8 @@ Examples:
                        help="Enable process hooks (native libs, runtime, DEX unpacking)")
     hooks.add_argument("--hooks-services", required=False, action="store_const", const=True, default=False,
                        help="Enable service hooks (bluetooth, camera, clipboard, location, telephony)")
+    hooks.add_argument("--hooks-bypass", required=False, action="store_const", const=True, default=False,
+                       help="Enable anti-analysis bypass hooks (root, frida, debugger, emulator detection)")
     
     # Individual hook arguments
     hooks.add_argument("--enable-aes", action="store_true", help="Enable AES hooks")
@@ -221,6 +231,7 @@ Examples:
     hooks.add_argument("--enable-clipboard", action="store_true", help="Enable clipboard hooks")
     hooks.add_argument("--enable-location", action="store_true", help="Enable location hooks")
     hooks.add_argument("--enable-telephony", action="store_true", help="Enable telephony hooks")
+    hooks.add_argument("--enable-bypass", action="store_true", help="Enable anti-analysis bypass hooks")
     
     parsed = parser.parse_args()
     script_name = sys.argv[0]
@@ -273,6 +284,9 @@ Examples:
             if parsed.enable_fritap:
                 print(f"[*] fritap enabled - output directory: {parsed.fritap_output_dir}")
             
+            if parsed.custom_script:
+                print(f"[*] custom scripts enabled: {', '.join(parsed.custom_script)}")
+            
             # Create AppProfiler with target and spawn mode information
             profiler = AppProfiler(
                 process_session, 
@@ -285,7 +299,8 @@ Examples:
                 enable_fritap=parsed.enable_fritap, 
                 fritap_output_dir=parsed.fritap_output_dir,
                 target_name=target_process,
-                spawn_mode=parsed.spawn
+                spawn_mode=parsed.spawn,
+                custom_scripts=parsed.custom_script
             )
             
             # Handle fritap spawn mode - attach to target after fritap initializes
